library(foreign)
library(survival)
library(norm)

Leader.data <- read.dta("C:/My Documents/leaders/data/toR.dta", convert.dates=FALSE)

attach(Leader.data)

summary(Leader.data)

median(t)
median(t)/365.25
(median(t)/365.25-as.integer(median(t)/365.25))*12
median(t[mixed==1])
median(t[mixed==1])/365.25
median(t[demparl==1])
median(t[demparl==1])/365.25
median(t[dempres==1])
median(t[dempres==1])/365.25
median(t[autoc==1])
median(t[autoc==1])/365.25

#Leader.data$t <- round(t,6)
#Leader.data$t0 <- round(t0,6)

Leader.data$txmixed <- log(t)*mixed
Leader.data$txdemparl <- log(t)*demparl
Leader.data$txdempres <- log(t)*dempres
Leader.data$txcivwar <- log(t)*civwar
Leader.data$txlnencap <- log(t)*lnencap
Leader.data$txlntropen <- log(t)*lntropen
Leader.data$txlnpop <- log(t)*lnpop
Leader.data$txage <- log(t)*age
Leader.data$txiniwar <- log(t)*iniwar

model1 <- coxph(Surv(t0, t, d) ~ mixed + demparl + dempres 
                               + civwar 
                               + lnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop
                               + age + powtimes
                               + inish + tginvsh
                               + dwinsh + dlosesh + ddrawsh
                               + iniwar + tginvwar
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=Leader.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

fit.model1 <- cox.zph(model1, transform='log')

detach(Leader.data)
attach(Leader.data)

L <- as.matrix(Leader.data[,c('t','t0','d',
                     'mixed','txmixed','demparl','txdemparl','dempres','txdempres',
                     'civwar','txcivwar','lnencap','txlnencap','encapchg',
                     'lntropen','tropenchg',
                     'lnpop','txlnpop',
                     'age','txage','powtimes',
                     'inish','tginvsh','dwinsh','dlosesh','ddrawsh',
                     'iniwar','txiniwar',
                     'tginvwar','dwinwar','dlosewar','ddrawwar')])

detach(Leader.data)

s <- prelim.norm(L)
thetahat.0 <- em.norm(s,criterion=1e-09)

thetahat <- thetahat.0
thetahat <- getparam.norm(s,thetahat)

set.seed(1510)
trk <- seq(1,nrow(L),1)
boot.1 <- sample(trk,1+abs(nrow(L)/4),replace=TRUE)

s.1 <- prelim.norm(L[boot.1,])
thetahat.1 <- em.norm(s.1, criterion=1e-09)
thetahat.1 <- getparam.norm(s.1,thetahat.1)

thetahat$mu <- thetahat.1$mu
thetahat$sigma <- thetahat.1$sigma

thetahat <- makeparam.norm(s,thetahat)

rngseed(1510)
theta.1 <- da.norm(s,thetahat,steps=500,showits=TRUE)
L.1 <- as.data.frame(imp.norm(s,theta.1,L))

L.1$ccode <- Leader.data$ccode

# model1.tx <- update(model1, .~. + txmixed + txdemparl + txdempres + txcivwar + txlnencap + txlnpop + txage)
model1.tx <- coxph(Surv(t0, t, d) ~ mixed + txmixed + demparl + txdemparl + dempres + txdempres
                               + civwar # + txcivwar
                               + lnencap + txlnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop + txlnpop
                               + age + txage + powtimes
                               + inish + tginvsh
                               + dwinsh + dlosesh + ddrawsh
                               + iniwar # + txiniwar 
                               + tginvwar
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=Leader.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


model1.L1 <- coxph(Surv(t0, t, d) ~ mixed + demparl + dempres 
                               + civwar 
                               + lnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop
                               + age + powtimes
                               + inish + tginvsh
                               + dwinsh + dlosesh + ddrawsh
                               + iniwar + tginvwar
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

fit.model1.L1 <- cox.zph(model1.L1, transform='log')





model1.tx.L1 <- coxph(Surv(t0, t, d) ~ mixed + txmixed + demparl + txdemparl + dempres + txdempres
                               + civwar + txcivwar
                               + lnencap + txlnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop + txlnpop
                               + age + txage + powtimes
                               + inish + tginvsh
                               + dwinsh + dlosesh + ddrawsh
                               + iniwar + txiniwar + tginvwar
                               + dwinwar + dlosewar + ddrawwar
                               + frailty(ccode), na.action=na.exclude, data=L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


m1.coef.L1 <- list(coef(model1.tx.L1))
m1.se.L1 <- list(sqrt(diag(vcov(model1.tx.L1))))

attach(Leader.data)

Leader.data$mixdwinsh <- mixed*dwinsh
Leader.data$mixdlosesh <- mixed*dlosesh
Leader.data$mixddrawsh <- mixed*ddrawsh

Leader.data$dparldwinsh <- demparl*dwinsh
Leader.data$dparldlosesh <- demparl*dlosesh
Leader.data$dparlddrawsh <- demparl*ddrawsh

Leader.data$dpresdwinsh <- dempres*dwinsh
Leader.data$dpresdlosesh <- dempres*dlosesh
Leader.data$dpresddrawsh <- dempres*ddrawsh

Leader.data$autdwinsh <- autoc*dwinsh
Leader.data$autdlosesh <- autoc*dlosesh
Leader.data$autddrawsh <- autoc*ddrawsh


Leader.data$mixdwinwar <- mixed*dwinwar
Leader.data$mixdlosewar <- mixed*dlosewar
Leader.data$mixddrawwar <- mixed*ddrawwar


Leader.data$dparldwinwar <- demparl*dwinwar
Leader.data$dparldlosewar <- demparl*dlosewar
Leader.data$dparlddrawwar <- demparl*ddrawwar


Leader.data$dpresdwinwar <- dempres*dwinwar
Leader.data$dpresdlosewar <- dempres*dlosewar
Leader.data$dpresddrawwar <- dempres*ddrawwar



Leader.data$autdwinwar <- autoc*dwinwar
Leader.data$autdlosewar <- autoc*dlosewar
Leader.data$autddrawwar <- autoc*ddrawwar


L.1$mixdwinsh <- mixed*dwinsh
L.1$mixdlosesh <- mixed*dlosesh
L.1$mixddrawsh <- mixed*ddrawsh


L.1$dparldwinsh <- demparl*dwinsh
L.1$dparldlosesh <- demparl*dlosesh
L.1$dparlddrawsh <- demparl*ddrawsh


L.1$dpresdwinsh <- dempres*dwinsh
L.1$dpresdlosesh <- dempres*dlosesh
L.1$dpresddrawsh <- dempres*ddrawsh


L.1$autdwinsh <- autoc*dwinsh
L.1$autdlosesh <- autoc*dlosesh
L.1$autddrawsh <- autoc*ddrawsh

L.1$mixdwinwar <- mixed*dwinwar
L.1$mixdlosewar <- mixed*dlosewar
L.1$mixddrawwar <- mixed*ddrawwar

L.1$dparldwinwar <- demparl*dwinwar
L.1$dparldlosewar <- demparl*dlosewar
L.1$dparlddrawwar <- demparl*ddrawwar

L.1$dpresdwinwar <- dempres*dwinwar
L.1$dpresdlosewar <- dempres*dlosewar
L.1$dpresddrawwar <- dempres*ddrawwar

L.1$autdwinwar <- autoc*dwinwar
L.1$autdlosewar <- autoc*dlosewar
L.1$autddrawwar <- autoc*ddrawwar


detach(Leader.data)


model2 <- coxph(Surv(t0, t, d) ~ mixed + demparl + dempres 
                               + civwar 
                               + lnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop
                               + age + powtimes
                               + inish + tginvsh
                               + autdwinsh + autdlosesh + autddrawsh
                               + mixdwinsh + mixdlosesh + mixddrawsh
                               + dparldwinsh + dparldlosesh + dparlddrawsh
                               + dpresdwinsh + dpresdlosesh + dpresddrawsh
                               + iniwar + tginvwar
                               + autdwinwar + autdlosewar + autddrawwar
                               + mixdwinwar + mixdlosewar + mixddrawwar
                               + dparldwinwar + dparldlosewar + dparlddrawwar
                               + dpresdwinwar + dpresdlosewar + dpresddrawwar
                               + frailty(ccode), na.action=na.exclude, data=Leader.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))

fit.model2 <- cox.zph(model2, transform='log')



model2.tx <- coxph(Surv(t0, t, d) ~ mixed + txmixed + demparl + txdemparl + dempres + txdempres
                               + civwar # + txcivwar
                               + lnencap + txlnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop + txlnpop
                               + age + txage + powtimes
                               + inish + tginvsh
                               + autdwinsh + autdlosesh + autddrawsh
                               + mixdwinsh + mixdlosesh + mixddrawsh
                               + dparldwinsh + dparldlosesh + dparlddrawsh
                               + dpresdwinsh + dpresdlosesh + dpresddrawsh
                               + iniwar # + txiniwar 
                               + tginvwar
                               + autdwinwar + autdlosewar + autddrawwar
                               + mixdwinwar + mixdlosewar + mixddrawwar
                               + dparldwinwar + dparldlosewar + dparlddrawwar
                               + dpresdwinwar + dpresdlosewar + dpresddrawwar
                               + frailty(ccode), na.action=na.exclude, data=Leader.data,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))



model2.L1 <- coxph(Surv(t0, t, d) ~ mixed + demparl + dempres 
                               + civwar 
                               + lnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop
                               + age + powtimes
                               + inish + tginvsh                               
                               + autdwinsh + autdlosesh + autddrawsh
                               + mixdwinsh + mixdlosesh + mixddrawsh
                               + dparldwinsh + dparldlosesh + dparlddrawsh
                               + dpresdwinsh + dpresdlosesh + dpresddrawsh
                               + iniwar + tginvwar
                               + autdwinwar + autdlosewar + autddrawwar
                               + mixdwinwar + mixdlosewar + mixddrawwar
                               + dparldwinwar + dparldlosewar + dparlddrawwar
                               + dpresdwinwar + dpresdlosewar + dpresddrawwar
                               + frailty(ccode), na.action=na.exclude, data=L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))


fit.model2.L1 <- cox.zph(model2.L1, transform='log')


model2.tx.L1 <- coxph(Surv(t0, t, d) ~ mixed + txmixed + demparl + txdemparl + dempres + txdempres
                               + civwar + txcivwar
                               + lnencap + txlnencap + encapchg 
                               + lntropen + tropenchg 
                               + lnpop + txlnpop
                               + age + txage + powtimes
                               + inish + tginvsh
                               + autdwinsh + autdlosesh + autddrawsh
                               + mixdwinsh + mixdlosesh + mixddrawsh
                               + dparldwinsh + dparldlosesh + dparlddrawsh
                               + dpresdwinsh + dpresdlosesh + dpresddrawsh
                               + iniwar +txiniwar + tginvwar
                               + autdwinwar + autdlosewar + autddrawwar
                               + mixdwinwar + mixdlosewar + mixddrawwar
                               + dparldwinwar + dparldlosewar + dparlddrawwar
                               + dpresdwinwar + dpresdlosewar + dpresddrawwar
                               + frailty(ccode), na.action=na.exclude, data=L.1,
                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))



m2.coef.L1 <- list(coef(model2.tx.L1))
m2.se.L1 <- list(sqrt(diag(vcov(model2.tx.L1))))

Ht.L1 <- basehaz(model2.tx.L1,centered=FALSE)
