# model 1

# model 1 -- table for proportional hazard test
# correction for p-values using Li, Meng, Raghunathan, and Rubin (1991)
# formula from page 590 of Rubin and Schenker, Statistics in Medicine (1991)
# also from page 68 of Allison (2002)

M <- 5

m1.rho <- cbind(fit.model1.L1$table[,1],fit.model1.L2$table[,1],fit.model1.L3$table[,1],fit.model1.L4$table[,1],
                fit.model1.L5$table[,1])

m1.rho.chi <- cbind(fit.model1.L1$table[,2],fit.model1.L2$table[,2],fit.model1.L3$table[,2],fit.model1.L4$table[,2],
                fit.model1.L5$table[,2])

m1.rho.bar <- apply(m1.rho,1,mean) 

m1.d.bar <- apply(m1.rho.chi,1,mean)

m1.s2.rho <- apply(sqrt(m1.rho.chi),1,var)

m1.D.tilde <- (m1.d.bar-(1-1/M)*m1.s2.rho)/(1+(1+1/M)*m1.s2.rho)

m1.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m1.s2.rho)^(-1))^2

m1.rho.imp <- round(cbind('rho'=m1.rho.bar,'D.tilde'=m1.D.tilde,'p-value'=pf(m1.D.tilde,1,m1.b.rho.df,lower.tail=FALSE)),3)

# model 1 -- coefficients

m1.b <- c(m1.coef.L1,m1.coef.L2,m1.coef.L3,m1.coef.L4,m1.coef.L5)
m1.s <- c(m1.se.L1,m1.se.L2,m1.se.L3,m1.se.L4,m1.se.L5)

model1.imp <- mi.inference(m1.b,m1.s)

round(cbind('b'=model1.imp$est,'std.err'=model1.imp$std.err,'p-value'=model1.imp$signif),3)

# model 1 -- log likelihood
m1.llk <- mean(c(model1.tx.L1$loglik[2],model1.tx.L2$loglik[2],model1.tx.L3$loglik[2],model1.tx.L4$loglik[2],
               model1.tx.L5$loglik[2]))

# model 1 -- Wald tests

k <- nrow(vcov(model1.tx.L1))

m1.U <- (vcov(model1.tx.L1)+vcov(model1.tx.L2)+vcov(model1.tx.L3)+vcov(model1.tx.L4)+vcov(model1.tx.L5))/M

m1.A <- diag(1,k,k)

m1.zz1 <- (model1.tx.L1$coef - model1.imp$est)%*%t(model1.tx.L1$coef - model1.imp$est)
m1.zz2 <- (model1.tx.L2$coef - model1.imp$est)%*%t(model1.tx.L2$coef - model1.imp$est)
m1.zz3 <- (model1.tx.L3$coef - model1.imp$est)%*%t(model1.tx.L3$coef - model1.imp$est)
m1.zz4 <- (model1.tx.L4$coef - model1.imp$est)%*%t(model1.tx.L4$coef - model1.imp$est)
m1.zz5 <- (model1.tx.L5$coef - model1.imp$est)%*%t(model1.tx.L5$coef - model1.imp$est)

m1.B <- (m1.zz1+m1.zz2+m1.zz3+m1.zz4+m1.zz5)/(M-1)

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

#m1.V <- (1+m1.rm)*m1.U

m1.Dm <- t(m1.A%*%model1.imp$est)%*%solve(m1.A%*%m1.U%*%t(m1.A))%*%(m1.A%*%model1.imp$est)/((1+m1.rm)*k)

m1.a <- 1-2/(k*(M-1))
m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2

m1.pval.Wald <- pf(m1.Dm,k,m1.v,lower.tail=FALSE)

# Wald test -- H0: demparl == dempres

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[3] <- 1
Q[5] <- -1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.dems <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.dems <- pf(W.dems,k,m1.v,lower.tail=FALSE)

# Wald test -- H0: txdemparl == txdempres

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[4] <- 1
Q[6] <- -1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.txdems <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.txdems <- pf(W.txdems,k,m1.v,lower.tail=FALSE)






# Wald test -- H0: lose crisis == lose war

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[22] <- 1
Q[28] <- -1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.lose <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.lose <- pf(W.lose,k,m1.v,lower.tail=FALSE)


# Wald test -- H0: win crisis == win war

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[21] <- 1
Q[27] <- -1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.win <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.win <- pf(W.win,k,m1.v,lower.tail=FALSE)


# Wald test -- H0: win crisis + lose crisis == 0


k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[21] <- 1
Q[22] <- 1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.winlose.0 <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.winlose.0 <- pf(W.winlose.0,k,m1.v,lower.tail=FALSE)


# Wald test -- H0: win war + lose war == 0

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[27] <- 1
Q[28] <- 1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.winlose.w0 <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.winlose.w0 <- pf(W.winlose.w0,k,m1.v,lower.tail=FALSE)




# Wald test -- H0: win crisis + lose crisis == win war + lose war

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[21] <- -1
Q[22] <- -1
Q[27] <- 1
Q[28] <- 1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.winlose <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.winlose <- pf(W.winlose,k,m1.v,lower.tail=FALSE)


# Wald test -- H0: draw war == draw crisis

k <- 1

Q <- as.matrix(t(rep(0,29)))
Q[23] <- 1
Q[29] <- -1

m1.rm <- (1+1/M)*sum(diag(m1.B%*%solve(m1.U)))/k

W.draw <- t(Q%*%model1.imp$est)%*%solve(Q%*%m1.U%*%t(Q))%*%(Q%*%model1.imp$est)/((1+m1.rm)*k)

#m1.a <- 1-2/(k*(M-1))
#m1.v <- 4+(k*(M-1)-4)*(1+m1.a/m1.rm)^2


m1.v <- .5*k*(M-1)*(1+1/k)*(1+m1.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.draw <- pf(W.draw,k,m1.v,lower.tail=FALSE)







# frailty terms

m1.frailty <- mean(c(model1.tx.L1$history$"frailty(ccode)"$history[10,1],
                     model1.tx.L2$history$"frailty(ccode)"$history[10,1],
                     model1.tx.L3$history$"frailty(ccode)"$history[10,1],
                     model1.tx.L4$history$"frailty(ccode)"$history[10,1],
                     model1.tx.L5$history$"frailty(ccode)"$history[10,1]))




round(pgamma(1,1/m1.frailty,1/m1.frailty),3)
round(qgamma(.025,1/m1.frailty,1/m1.frailty),3)
round(qgamma(.975,1/m1.frailty,1/m1.frailty),3)

m1.frail.terms <- exp((model1.tx.L1$frail+model1.tx.L2$frail+model1.tx.L3$frail+model1.tx.L4$frail+model1.tx.L5$frail)/5)

quantile(m1.frail.terms,probs=seq(0,1,.01))

cbind(m1.frail.terms,rep(NA,166))

max(m1.frail.terms)
min(m1.frail.terms)

m1.k.theta <- 136 # see df from model1.tx.L1 for example
m1.d.bar.theta <- mean(c(1040.75,1041.30,1038.44,1055.88,1038.50))
m1.s2.theta <- var(c(1040.75,1041.30,1038.44,1055.88,1038.50)^.5)

m1.D.tilde.theta <- (m1.d.bar.theta/m1.k.theta - (1-1/M)*m1.s2.theta)/(1+(1+1/M)*m1.s2.theta)

m1.b.theta <- (m1.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m1.s2.theta)^(-1))^2

m1.frail.pval <- pf(m1.D.tilde.theta,m1.k.theta,m1.b.theta,lower.tail=FALSE)


# time to zero effects

exp(-model1.imp$est[1]/model1.imp$est[2])/365.25 # mixed
exp(-model1.imp$est[3]/model1.imp$est[4])/365.25 # demparl
exp(-model1.imp$est[5]/model1.imp$est[6])/365.25 # dempres

exp((model1.imp$est[1]-model1.imp$est[5])/(model1.imp$est[6]-model1.imp$est[2]))/365.25
exp((model1.imp$est[3]-model1.imp$est[5])/(model1.imp$est[6]-model1.imp$est[4]))/365.25


m1.Tm <- m1.U+(1+1/M)*m1.B

2*pt(abs(model1.imp$est[1]+model1.imp$est[2]*log(365.25*10.5))/sqrt(m1.Tm[1,1]+(log(365.25*10.5))^2*m1.Tm[2,2]
      +2*log(365.25*10.5)*m1.Tm[2,1]),200,lower.tail=FALSE)
2*pt(abs(model1.imp$est[1]+model1.imp$est[2]*log(365.25*10.6))/sqrt(m1.Tm[1,1]+(log(365.25*10.6))^2*m1.Tm[2,2]
     +2*log(365.25*10.6)*m1.Tm[2,1]),200, lower.tail=FALSE)
2*pt(abs(model1.imp$est[1]+model1.imp$est[2]*log(365.25*10.7))/sqrt(m1.Tm[1,1]+(log(365.25*10.7))^2*m1.Tm[2,2]
     +2*log(365.25*10.7)*m1.Tm[2,1]),200,lower.tail=FALSE)

2*pt(abs(model1.imp$est[1]+model1.imp$est[2]*log(365.25*30))/sqrt(m1.Tm[1,1]+(log(365.25*30))^2*m1.Tm[2,2]
      +2*log(365.25*30)*m1.Tm[2,1]),200,lower.tail=FALSE)
2*pt(abs(model1.imp$est[1]+model1.imp$est[2]*log(365.25*38))/sqrt(m1.Tm[1,1]+(log(365.25*38))^2*m1.Tm[2,2]
     +2*log(365.25*38)*m1.Tm[2,1]),200,lower.tail=FALSE)

exp(-model1.imp$est[9]/model1.imp$est[10])/365.25 # lnencap

2*pt(abs(model1.imp$est[9]+model1.imp$est[10]*log(365.25*3))/sqrt(m1.Tm[9,9]+(log(365.25*3))^2*m1.Tm[10,10]
     +2*log(365.25*3)*m1.Tm[10,9]),200,lower.tail=FALSE)
2*pt(abs(model1.imp$est[9]+model1.imp$est[10]*log(365.25*9))/sqrt(m1.Tm[9,9]+(log(365.25*9))^2*m1.Tm[10,10]
     +2*log(365.25*9)*m1.Tm[10,9]),200,lower.tail=FALSE)

exp(-model1.imp$est[14]/model1.imp$est[15])/365.25 # lnpop

2*pt(abs(model1.imp$est[14]+model1.imp$est[15]*log(365.25*2.5))/sqrt(m1.Tm[14,14]+(log(365.25*2.5))^2*m1.Tm[15,15]
     +2*log(365.25*2.5)*m1.Tm[15,14]),200,lower.tail=FALSE)


exp(-model1.imp$est[16]/model1.imp$est[17])/365.25 # age


exp(-model1.imp$est[24]/model1.imp$est[25])/365.25  # warini

2*pt(abs(model1.imp$est[24]+model1.imp$est[25]*log(365.25*100))/sqrt(m1.Tm[24,24]+(log(365.25*100))^2*m1.Tm[25,25]
     +2*log(365.25*100)*m1.Tm[25,24]),200, lower.tail=FALSE)


# civil war

2*pt(abs(model1.imp$est[7]+model1.imp$est[8]*log(365.25*.1))/sqrt(m1.Tm[7,7]+(log(365.25*.1))^2*m1.Tm[8,8]
      +2*log(365.25*.1)*m1.Tm[8,7]),200,lower.tail=FALSE)

2*pt(abs(model1.imp$est[7]+model1.imp$est[8]*log(365.25*.5))/sqrt(m1.Tm[7,7]+(log(365.25*.5))^2*m1.Tm[8,8]
      +2*log(365.25*.5)*m1.Tm[8,7]),200,lower.tail=FALSE)




m1.part1 <- round(cbind('b'=model1.imp$est,'std.err'=model1.imp$std.err,'p-value'=model1.imp$signif),3)[1:18,]
m1.part1 <- rbind(m1.part1,
                  'No. of obs.'=c(as.integer(model1.tx.L1$n),NA,NA),
                  'No. of subjects'=c(2049,NA,NA), # no. subjects
                  'No. of failures'=c(1828,NA,NA), # no. failures
                  'Log-likelihood'=c(m1.llk,NA,NA), # log-llk
                  'Wald-test'=c(m1.Dm,m1.pval.Wald,NA), # wald test
                  'Theta'=c(m1.frailty,m1.D.tilde.theta,m1.frail.pval)) # frailty




# model 2

# model 2 -- table for proportional hazard test

M <- 5

m2.rho <- cbind(fit.model2.L1$table[,1],fit.model2.L2$table[,1],fit.model2.L3$table[,1],fit.model2.L4$table[,1],
                fit.model2.L5$table[,1])

m2.rho.chi <- cbind(fit.model2.L1$table[,2],fit.model2.L2$table[,2],fit.model2.L3$table[,2],fit.model2.L4$table[,2],
                fit.model2.L5$table[,2])

m2.rho.bar <- apply(m2.rho,1,mean) 

m2.d.bar <- apply(m2.rho.chi,1,mean)

m2.s2.rho <- apply(sqrt(m2.rho.chi),1,var)

m2.D.tilde <- (m2.d.bar-(1-1/M)*m2.s2.rho)/(1+(1+1/M)*m2.s2.rho)

m2.b.rho.df <- 1^(-3/M)*(M-1)*(1+((1+1/M)*m2.s2.rho)^(-1))^2

m2.rho.imp <- round(cbind('rho'=m2.rho.bar,'D.tilde'=m2.D.tilde,'p-value'=pf(m2.D.tilde,1,m2.b.rho.df,lower.tail=FALSE)),3)

# model 2 -- coefficients

m2.b <- c(m2.coef.L1,m2.coef.L2,m2.coef.L3,m2.coef.L4,m2.coef.L5)
m2.s <- c(m2.se.L1,m2.se.L2,m2.se.L3,m2.se.L4,m2.se.L5)

model2.imp <- mi.inference(m2.b,m2.s)

round(cbind('b'=model2.imp$est,'std.err'=model2.imp$std.err,'p-value'=model2.imp$signif),3)

# model 2 -- log likelihood
m2.llk <- mean(c(model2.tx.L1$loglik[2],model2.tx.L2$loglik[2],model2.tx.L3$loglik[2],model2.tx.L4$loglik[2],
               model2.tx.L5$loglik[2]))



# model2 -- Wald test

k <- nrow(vcov(model2.tx.L1))

m2.U <- (vcov(model2.tx.L1)+vcov(model2.tx.L2)+vcov(model2.tx.L3)+vcov(model2.tx.L4)+vcov(model2.tx.L5))/M

m2.A <- diag(1,k,k)

m2.zz1 <- (model2.tx.L1$coef - model2.imp$est)%*%t(model2.tx.L1$coef - model2.imp$est)
m2.zz2 <- (model2.tx.L2$coef - model2.imp$est)%*%t(model2.tx.L2$coef - model2.imp$est)
m2.zz3 <- (model2.tx.L3$coef - model2.imp$est)%*%t(model2.tx.L3$coef - model2.imp$est)
m2.zz4 <- (model2.tx.L4$coef - model2.imp$est)%*%t(model2.tx.L4$coef - model2.imp$est)
m2.zz5 <- (model2.tx.L5$coef - model2.imp$est)%*%t(model2.tx.L5$coef - model2.imp$est)

m2.B <- (m2.zz1+m2.zz2+m2.zz3+m2.zz4+m2.zz5)/(M-1)

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

#m2.V <- (1+m2.rm)*m2.U

m2.Dm <- t(m2.A%*%model2.imp$est)%*%solve(m2.A%*%m2.U%*%t(m2.A))%*%(m2.A%*%model2.imp$est)/((1+m2.rm)*k)

m2.a <- 1-2/(k*(M-1))
m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2

m2.pval.Wald <- pf(m2.Dm,k,m2.v,lower.tail=FALSE)

# Wald test : autlosewar==mixlosewar

k <- 1

Q <- as.matrix(t(rep(0,47)))
Q[37] <- 1
Q[40] <- -1

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autmixlose <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autmixlose <- pf(W.autmixlose,k,m2.v,lower.tail=FALSE)




# Wald test : autwinsh+autlosesh+autdrawsh==autwinwar+autlosewar+autdrawwar

k <- 1

Q <- as.matrix(t(rep(0,47)))

Q[21] <- -1
Q[22] <- -1
Q[23] <- -1
Q[36] <- 1
Q[37] <- 1
Q[38] <- 1

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autsh.autwar <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autsh.autwar <- pf(W.autsh.autwar,k,m2.v,lower.tail=FALSE)



# Wald test : autwinsh+autlosesh==autwinwar+autlosewar

k <- 1

Q <- as.matrix(t(rep(0,47)))

Q[21] <- 1
Q[22] <- 1
Q[36] <- -1
Q[37] <- -1


m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autwlsh.autwlwar <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autwlsh.autwlwar <- pf(W.autwlsh.autwlwar,k,m2.v,lower.tail=FALSE)



# Wald test : autwinwar==autwinsh

k <- 1

Q <- as.matrix(t(rep(0,47)))
Q[21] <- 1
Q[36] <- -1

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autwin <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autwin <- pf(W.autwin,k,m2.v,lower.tail=FALSE)




# Wald test : autlosewar==autlosesh

k <- 1

Q <- as.matrix(t(rep(0,47)))
Q[22] <- 1
Q[37] <- -1

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autlose <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autlose <- pf(W.autlose,k,m2.v,lower.tail=FALSE)



# Wald test : autdrawwar==autdrawsh

k <- 1

Q <- as.matrix(t(rep(0,47)))
Q[23] <- 1
Q[38] <- -1

m2.rm <- (1+1/M)*sum(diag(m2.B%*%solve(m2.U)))/k

W.autdraw <- t(Q%*%model2.imp$est)%*%solve(Q%*%m2.U%*%t(Q))%*%(Q%*%model2.imp$est)/((1+m2.rm)*k)

#m2.a <- 1-2/(k*(M-1))
#m2.v <- 4+(k*(M-1)-4)*(1+m2.a/m2.rm)^2


m2.v <- .5*k*(M-1)*(1+1/k)*(1+m2.rm^(-1))^2 # Meng and Rubin (1992, 105)

pval.W.autdraw <- pf(W.autdraw,k,m2.v,lower.tail=FALSE)





# model2 -- frailty

m2.frailty <- mean(c(model2.tx.L1$history$"frailty(ccode)"$history[10,1],
                     model2.tx.L2$history$"frailty(ccode)"$history[10,1],
                     model2.tx.L3$history$"frailty(ccode)"$history[10,1],
                     model2.tx.L4$history$"frailty(ccode)"$history[10,1],
                     model2.tx.L5$history$"frailty(ccode)"$history[10,1]))




round(pgamma(1,1/m2.frailty,1/m2.frailty),3)
round(qgamma(.025,1/m2.frailty,1/m2.frailty),3)
round(qgamma(.975,1/m2.frailty,1/m2.frailty),3)

m2.frail.terms <- exp((model2.tx.L1$frail+model2.tx.L2$frail+model2.tx.L3$frail+model2.tx.L4$frail+model2.tx.L5$frail)/5)

quantile(m2.frail.terms,probs=seq(0,1,.01))

cbind(m2.frail.terms,rep(NA,166))

max(m2.frail.terms)
min(m2.frail.terms)

m2.k.theta <- 136 # see df from model2.tx.L1 for example
m2.d.bar.theta <- mean(c(1030.07,1030.65,1027.29,1045.15,1028.12))
m2.s2.theta <- var(c(1030.07,1030.65,1027.29,1045.15,1028.12)^.5)

m2.D.tilde.theta <- (m2.d.bar.theta/m2.k.theta - (1-1/M)*m2.s2.theta)/(1+(1+1/M)*m2.s2.theta)

m2.b.theta <- (m2.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.s2.theta)^(-1))^2

m2.frail.pval <- pf(m2.D.tilde.theta,m2.k.theta,m2.b.theta,lower.tail=FALSE)


# time to zero effects

exp(-model2.imp$est[1]/model2.imp$est[2])/365.25 # mixed
exp(-model2.imp$est[3]/model2.imp$est[4])/365.25 # demparl
exp(-model2.imp$est[5]/model2.imp$est[6])/365.25 # dempres

m2.Tm <- m2.U+(1+1/M)*m2.B

2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*10))/sqrt(m2.Tm[1,1]+(log(365.25*10))^2*m2.Tm[2,2]+2*log(365.25*10)*m2.Tm[2,1]),100,
      lower.tail=FALSE)
2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*10.5))/sqrt(m2.Tm[1,1]+(log(365.25*10.5))^2*m2.Tm[2,2]+2*log(365.25*10.5)*m2.Tm[2,1]),100,
      lower.tail=FALSE)
2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*10.6))/sqrt(m2.Tm[1,1]+(log(365.25*10.6))^2*m2.Tm[2,2]+2*log(365.25*10.6)*m2.Tm[2,1]),100,
      lower.tail=FALSE)
2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*10.7))/sqrt(m2.Tm[1,1]+(log(365.25*10.7))^2*m2.Tm[2,2]+2*log(365.25*10.7)*m2.Tm[2,1]),100,
      lower.tail=FALSE)

2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*30))/sqrt(m2.Tm[1,1]+(log(365.25*30))^2*m2.Tm[2,2]+2*log(365.25*30)*m2.Tm[2,1]),100,
      lower.tail=FALSE)
2*pt(abs(model2.imp$est[1]+model2.imp$est[2]*log(365.25*39))/sqrt(m2.Tm[1,1]+(log(365.25*39))^2*m2.Tm[2,2]+2*log(365.25*39)*m2.Tm[2,1]),100,
      lower.tail=FALSE)

exp(-model2.imp$est[9]/model2.imp$est[10])/365.25 # lnencap

2*pt(abs(model2.imp$est[9]+model2.imp$est[10]*log(365.25*3))/sqrt(m2.Tm[9,9]+(log(365.25*3))^2*m2.Tm[10,10]+2*log(365.25*3)*m2.Tm[10,9]),100,
      lower.tail=FALSE)
2*pt(abs(model2.imp$est[9]+model2.imp$est[10]*log(365.25*9))/sqrt(m2.Tm[9,9]+(log(365.25*9))^2*m2.Tm[10,10]+2*log(365.25*9)*m2.Tm[10,9]),100,
      lower.tail=FALSE)

exp(-model2.imp$est[14]/model2.imp$est[15])/365.25 # lnpop

2*pt(abs(model2.imp$est[14]+model2.imp$est[15]*log(365.25*2.5))/sqrt(m2.Tm[14,14]+(log(365.25*2.5))^2*m2.Tm[15,15]+2*log(365.25*2.5)*m2.Tm[15,14]),100,
      lower.tail=FALSE)


exp(-model2.imp$est[16]/model2.imp$est[17])/365.25 # age







m2.part1 <- round(cbind('b'=model2.imp$est,'std.err'=model2.imp$std.err,'p-value'=model2.imp$signif),3)[1:18,]
m2.part1 <- rbind(m2.part1,
                  'No. of obs.'=c(as.integer(model2.tx.L1$n),NA,NA),
                  'No. of subjects'=c(2049,NA,NA), # no. subjects
                  'No. of failures'=c(1828,NA,NA), # no. failures
                  'Log-likelihood'=c(m2.llk,NA,NA), # log-llk
                  'Wald-test'=c(m2.Dm,m2.pval.Wald,NA), # wald test
                  'Theta'=c(m2.frailty,m2.D.tilde.theta,m2.frail.pval)) # frailty



# model1 -- part 2

m1.part2 <- round(cbind('b'=model1.imp$est,'std.err'=model1.imp$std.err,'p-value'=model1.imp$signif),3)[19:29,]


# model2 -- part 2

m2.part2 <- round(cbind('b'=model2.imp$est,'std.err'=model2.imp$std.err,'p-value'=model2.imp$signif),3)[19:47,]




ttrk0 <- cbind(rbind(m1.part2[1:2,],m1.part2[6:8,]),rbind(m2.part2[1:2,],m2.part2[15:17,]))

ttrk1 <- cbind(rbind(m1.part2[3:5,],m1.part2[9:11,]),cbind(rep(NA,6),rep(NA,6),rep(NA,6)))

ttrk2 <- cbind(cbind(rep(NA,12),rep(NA,12),rep(NA,12)),m2.part2[3:14,])

ttrk3 <- cbind(cbind(rep(NA,12),rep(NA,12),rep(NA,12)),m2.part2[18:29,])

# latex tabels

library(Hmisc)

part1 <- round(cbind(m1.part1,m2.part1),3)

part2 <- round(rbind(ttrk0,ttrk1,ttrk2,ttrk3),3)

models.part1 <- latex(part1, file='C:/My Documents/leaders/paper/lt/part1.latex.tex', ctable=TRUE,
                  label='tab:part1', cgroup=c('Model 1','Model 2'), n.cgroup=c(3,3))



models.part2 <- latex(part2, file='C:/My Documents/leaders/paper/lt/part2.latex.tex', ctable=TRUE,
                      label='tab:part2', cgroup=c('Model 1','Model 2'), n.cgroup=c(3,3))
                      


# latex tables for the proportional effects


propeff.t1 <- latex(m1.rho.imp, file='C:/My Documents/leaders/paper/lt/propeff1.latex.tex', ctable=TRUE,
                    label='tab:propeff1')
                    

propeff.t2 <- latex(m2.rho.imp, file='C:/My Documents/leaders/paper/lt/propeff2.latex.tex', ctable=TRUE,
                    label='tab:propeff2')


detach(package:Hmisc)


# save.image("C:/My Documents/leaders/R-models/lt-analysis/ajps-analysis.RData")


# model 1 with no time interactions

no1.coef.L1 <- list(coef(model1.L1))
no1.se.L1 <- list(sqrt(diag(vcov(model1.L1))))

no1.coef.L2 <- list(coef(model1.L2))
no1.se.L2 <- list(sqrt(diag(vcov(model1.L2))))

no1.coef.L3 <- list(coef(model1.L3))
no1.se.L3 <- list(sqrt(diag(vcov(model1.L3))))

no1.coef.L4 <- list(coef(model1.L4))
no1.se.L4 <- list(sqrt(diag(vcov(model1.L4))))

no1.coef.L5 <- list(coef(model1.L5))
no1.se.L5 <- list(sqrt(diag(vcov(model1.L5))))

no1.b <- c(no1.coef.L1,no1.coef.L2,no1.coef.L3,no1.coef.L4,no1.coef.L5)
no1.s <- c(no1.se.L1,no1.se.L2,no1.se.L3,no1.se.L4,no1.se.L5)

no1.imp <- mi.inference(no1.b,no1.s)

m1.notimeint <- round(cbind('b'=no1.imp$est,'std.err'=no1.imp$std.err,'p-value'=no1.imp$signif),3)

library(Hmisc)

models.m1.notime <- latex(m1.notimeint, file='C:/My Documents/leaders/paper/lt/m1.notimeint.latex.tex', ctable=TRUE,
                  label='tab:m1notime')

detach(package:Hmisc)

m1.notime.llk <- mean(c(model1.L1$loglik[2],model1.L2$loglik[2],model1.L3$loglik[2],model1.L4$loglik[2],
               model1.L5$loglik[2]))

k <- nrow(vcov(model1.L1))

m1.nt.U <- (vcov(model1.L1)+vcov(model1.L2)+vcov(model1.L3)+vcov(model1.L4)+vcov(model1.L5))/M

m1.nt.A <- diag(1,k,k)

m1.nt.zz1 <- (model1.L1$coef - no1.imp$est)%*%t(model1.L1$coef - no1.imp$est)
m1.nt.zz2 <- (model1.L2$coef - no1.imp$est)%*%t(model1.L2$coef - no1.imp$est)
m1.nt.zz3 <- (model1.L3$coef - no1.imp$est)%*%t(model1.L3$coef - no1.imp$est)
m1.nt.zz4 <- (model1.L4$coef - no1.imp$est)%*%t(model1.L4$coef - no1.imp$est)
m1.nt.zz5 <- (model1.L5$coef - no1.imp$est)%*%t(model1.L5$coef - no1.imp$est)

m1.nt.B <- (m1.nt.zz1+m1.nt.zz2+m1.nt.zz3+m1.nt.zz4+m1.nt.zz5)/(M-1)

m1.nt.rm <- (1+1/M)*sum(diag(m1.nt.B%*%solve(m1.nt.U)))/k

#m1.V <- (1+m1.rm)*m1.U

m1.nt.Dm <- t(m1.nt.A%*%no1.imp$est)%*%solve(m1.nt.A%*%m1.nt.U%*%t(m1.nt.A))%*%(m1.nt.A%*%no1.imp$est)/((1+m1.nt.rm)*k)

m1.nt.a <- 1-2/(k*(M-1))
m1.nt.v <- 4+(k*(M-1)-4)*(1+m1.nt.a/m1.nt.rm)^2

m1.nt.pval.Wald <- pf(m1.nt.Dm,k,m1.nt.v,lower.tail=FALSE)

m1.nt.frailty <- mean(c(model1.L1$history$"frailty(ccode)"$history[10,1],
                     model1.L2$history$"frailty(ccode)"$history[10,1],
                     model1.L3$history$"frailty(ccode)"$history[10,1],
                     model1.L4$history$"frailty(ccode)"$history[10,1],
                     model1.L5$history$"frailty(ccode)"$history[10,1]))


m1.nt.k.theta <- 112 # see df from model1.L1 for example
m1.nt.d.bar.theta <- mean(c(541.23,542.12,539.34,538.50,538.86))
m1.nt.s2.theta <- var(c(541.23,542.12,539.34,538.50,538.86)^.5)

m1.nt.D.tilde.theta <- (m1.nt.d.bar.theta/m1.nt.k.theta - (1-1/M)*m1.nt.s2.theta)/(1+(1+1/M)*m1.nt.s2.theta)

m1.nt.b.theta <- (m1.nt.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m1.nt.s2.theta)^(-1))^2

m1.nt.frail.pval <- pf(m1.nt.D.tilde.theta,m1.nt.k.theta,m1.nt.b.theta,lower.tail=FALSE)



# model 2 no time interactions


no2.coef.L1 <- list(coef(model2.L1))
no2.se.L1 <- list(sqrt(diag(vcov(model2.L1))))

no2.coef.L2 <- list(coef(model2.L2))
no2.se.L2 <- list(sqrt(diag(vcov(model2.L2))))

no2.coef.L3 <- list(coef(model2.L3))
no2.se.L3 <- list(sqrt(diag(vcov(model2.L3))))

no2.coef.L4 <- list(coef(model2.L4))
no2.se.L4 <- list(sqrt(diag(vcov(model2.L4))))

no2.coef.L5 <- list(coef(model2.L5))
no2.se.L5 <- list(sqrt(diag(vcov(model2.L5))))

no2.b <- c(no2.coef.L1,no2.coef.L2,no2.coef.L3,no2.coef.L4,no2.coef.L5)
no2.s <- c(no2.se.L1,no2.se.L2,no2.se.L3,no2.se.L4,no2.se.L5)

no2.imp <- mi.inference(no2.b,no2.s)

m2.notimeint <- round(cbind('b'=no2.imp$est,'std.err'=no2.imp$std.err,'p-value'=no2.imp$signif),3)

library(Hmisc)

models.m2.notime <- latex(m2.notimeint, file='C:/My Documents/leaders/paper/lt/m2.notimeint.latex.tex', ctable=TRUE,
                  label='tab:m2notime')

detach(package:Hmisc)


m2.notime.llk <- mean(c(model2.L1$loglik[2],model2.L2$loglik[2],model2.L3$loglik[2],model2.L4$loglik[2],
               model2.L5$loglik[2]))

k <- nrow(vcov(model2.L1))

m2.nt.U <- (vcov(model2.L1)+vcov(model2.L2)+vcov(model2.L3)+vcov(model2.L4)+vcov(model2.L5))/M

m2.nt.A <- diag(1,k,k)

m2.nt.zz1 <- (model2.L1$coef - no2.imp$est)%*%t(model2.L1$coef - no2.imp$est)
m2.nt.zz2 <- (model2.L2$coef - no2.imp$est)%*%t(model2.L2$coef - no2.imp$est)
m2.nt.zz3 <- (model2.L3$coef - no2.imp$est)%*%t(model2.L3$coef - no2.imp$est)
m2.nt.zz4 <- (model2.L4$coef - no2.imp$est)%*%t(model2.L4$coef - no2.imp$est)
m2.nt.zz5 <- (model2.L5$coef - no2.imp$est)%*%t(model2.L5$coef - no2.imp$est)

m2.nt.B <- (m2.nt.zz1+m2.nt.zz2+m2.nt.zz3+m2.nt.zz4+m2.nt.zz5)/(M-1)

m2.nt.rm <- (1+1/M)*sum(diag(m2.nt.B%*%solve(m2.nt.U)))/k

#m2.V <- (1+m2.rm)*m2.U

m2.nt.Dm <- t(m2.nt.A%*%no2.imp$est)%*%solve(m2.nt.A%*%m2.nt.U%*%t(m2.nt.A))%*%(m2.nt.A%*%no2.imp$est)/((1+m2.nt.rm)*k)

m2.nt.a <- 1-2/(k*(M-1))
m2.nt.v <- 4+(k*(M-1)-4)*(1+m2.nt.a/m2.nt.rm)^2

m2.nt.pval.Wald <- pf(m2.nt.Dm,k,m2.nt.v,lower.tail=FALSE)



m2.nt.frailty <- mean(c(model2.L1$history$"frailty(ccode)"$history[10,1],
                     model2.L2$history$"frailty(ccode)"$history[10,1],
                     model2.L3$history$"frailty(ccode)"$history[10,1],
                     model2.L4$history$"frailty(ccode)"$history[10,1],
                     model2.L5$history$"frailty(ccode)"$history[10,1]))


m2.nt.k.theta <- 112 # see df from model2.L1 for example
m2.nt.d.bar.theta <- mean(c(540.25,541.43,538.14,537.68,537.80))
m2.nt.s2.theta <- var(c(540.25,541.43,538.14,537.68,537.80)^.5)

m2.nt.D.tilde.theta <- (m2.nt.d.bar.theta/m2.nt.k.theta - (1-1/M)*m2.nt.s2.theta)/(1+(1+1/M)*m2.nt.s2.theta)

m2.nt.b.theta <- (m2.nt.k.theta)^(-3/M)*(M-1)*(1+((1+1/M)*m2.nt.s2.theta)^(-1))^2

m2.nt.frail.pval <- pf(m2.nt.D.tilde.theta,m2.nt.k.theta,m2.nt.b.theta,lower.tail=FALSE)


# list wise deletion

library(Hmisc)

propeff.listw1 <- latex(round(fit.model1$table,3), file='C:/My Documents/leaders/paper/lt/propeff1lw.latex.tex', ctable=TRUE,
                    label='tab:propeff1lw')
                    

propeff.listw2 <- latex(round(fit.model2$table,3), file='C:/My Documents/leaders/paper/lt/propeff2lw.latex.tex', ctable=TRUE,
                    label='tab:propeff2lw')



m1.list <- round(cbind('b'=model1.tx$coef,'std.err'=sqrt(diag(vcov(model1.tx))),
                 'p-value'=1-pchisq((model1.tx$coef)^2/diag(vcov(model1.tx)),1)),3)


m1.listw1 <- latex(m1.list, file='C:/My Documents/leaders/paper/lt/m1.lw.latex.tex', ctable=TRUE,
                    label='tab:m1lw')


m2.list <- round(cbind('b'=model2.tx$coef,'std.err'=sqrt(diag(vcov(model2.tx))),
                 'p-value'=1-pchisq((model2.tx$coef)^2/diag(vcov(model2.tx)),1)),3)



m2.listw1 <- latex(m2.list, file='C:/My Documents/leaders/paper/lt/m2.lw.latex.tex', ctable=TRUE,
                    label='tab:m2lw')



detach(package:Hmisc)


# coxph(Surv(t0, t, d) ~ mixed + txmixed + demparl + txdemparl + dempres + txdempres
#                               + civwar + txcivwar
#                               + lnencap + txlnencap + encapchg 
#                               + lntropen + tropenchg 
#                               + lnpop + txlnpop
#                               + age + txage + powtimes
#                               + inish + tginvsh
#                               + dwinsh + dlosesh + ddrawsh
#                               + mixdwinsh + mixdlosesh + mixddrawsh
#                               + dparldwinsh + dparldlosesh + dparlddrawsh
#                               + dpresdwinsh + dpresdlosesh + dpresddrawsh
#                               + iniwar + txiniwar + tginvwar
#                               + dwinwar + dlosewar + ddrawwar
#                               + mixdwinwar + mixdlosewar + mixddrawwar
#                               + dparldwinwar + dparldlosewar + dparlddrawwar
#                               + dpresdwinwar + dpresdlosewar + dpresddrawwar
#                               + frailty(ccode), na.action=na.exclude, data=L.5,
#                               control=coxph.control(eps=1e-09,iter.max=100,outer.max=100))
